{%- for user_name, user_details in users.items() %}
{%- if user_details.get('password') %}
username {{ user_name }} secret {{ user_details.password }}
{%- else %}
username {{ user_name }} nopassword
{%- endif %}
{%- if user_details.get('level') %}
username {{ user_name }} privilege {{ user_details.level }}
{%- endif %}
{%- if user_details.get('sshkeys') %}
{%- for sshkey in user_details.sshkeys %}
username {{ user_name }} sshkey {{ sshkey }}
{%- endfor %}
{%- endif %}
{%- endfor %}
